%define module rtree
%define srcname Rtree

Name:           python-%{module}
Version:        1.0.1
Release:        %mkrel 1
Summary:        R-Tree spatial index for Python GIS
Group:          Development/Python
License:        LGPLv2
URL:            https://pypi.python.org/pypi/Rtree
Source0:        https://files.pythonhosted.org/packages/source/R/%{srcname}/%{srcname}-%{version}.tar.gz

BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  spatialindex-devel
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel

BuildRequires:  python3-pytest
BuildRequires:  python3-numpy
BuildRequires:  locales-en

%description
Rtree is a ctypes Python wrapper of the spatialindex library, that
provides a number of advanced spatial indexing features for the
spatially curious Python user. These features include:

 -Nearest neighbor search
 -Intersection search
 -Multi-dimensional indexes
 -Clustered indexes (store Python pickles directly with index entries)
 -Bulk loading
 -Deletion
 -Disk serialization
 -Custom storage implementation
  (to implement spatial indexing in ZODB, for example)


%package -n python3-%{module}
Summary:        R-Tree spatial index for Python GIS
Group:          Development/Python
%{?python_provide:%python_provide python3-%{module}}
Requires:       libspatialindex

%description -n python3-%{module}
Rtree is a ctypes Python wrapper of the spatialindex library, that
provides a number of advanced spatial indexing features for the
spatially curious Python user. These features include:

 -Nearest neighbor search
 -Intersection search
 -Multi-dimensional indexes
 -Clustered indexes (store Python pickles directly with index entries)
 -Bulk loading
 -Deletion
 -Disk serialization
 -Custom storage implementation
  (to implement spatial indexing in ZODB, for example)


%prep
%autosetup -n Rtree-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files rtree

%if 0
%check
export LANG=C.UTF-8
PYTHONPATH="%{buildroot}%{python3_sitelib}" \
    py.test-%{python3_version} -ra tests
PYTHONPATH="%{buildroot}%{python3_sitelib}" \
    py.test-%{python3_version} -ra --doctest-modules rtree
%endif

%files -n python3-%{module} -f %{pyproject_files}
%license LICENSE.txt
%doc README.md


%changelog
* Wed Nov 09 2022 daviddavid <daviddavid> 1.0.1-1.mga9
+ Revision: 1904905
- new version: 1.0.1

* Sat Sep 17 2022 papoteur <papoteur> 1.0.0-4.mga9
+ Revision: 1889534
- fix require on libspatialindex

* Sat Sep 17 2022 papoteur <papoteur> 1.0.0-3.mga9
+ Revision: 1889518
- Add missing Requires on libspatialindex.so.6

* Thu Sep 08 2022 neoclust <neoclust> 1.0.0-2.mga9
+ Revision: 1885997
- Do not remove setup.cfg, it helps for version provides

* Wed Sep 07 2022 neoclust <neoclust> 1.0.0-1.mga9
+ Revision: 1885241
- New version  1.0.0

* Tue Mar 29 2022 umeabot <umeabot> 0.9.7-4.mga9
+ Revision: 1831658
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 mrambo3501 <mrambo3501> 0.9.7-3.mga9
+ Revision: 1782697
- rebuild for python-3.10

* Mon Mar 22 2021 daviddavid <daviddavid> 0.9.7-2.mga9
+ Revision: 1707315
- rebuild for python 3.9

* Fri Mar 12 2021 daviddavid <daviddavid> 0.9.7-1.mga9
+ Revision: 1701646
- new version: 0.9.7

* Thu Jan 07 2021 daviddavid <daviddavid> 0.9.4-1.mga8
+ Revision: 1669416
- initial package python-rtree (needed for spyder)

